import {
  ChangeDetectorRef,
  Component,
  ElementRef,
  EventEmitter,
  Input,
  OnInit,
  Output,
} from '@angular/core';
import { FormGroup } from '@angular/forms';
// eslint-disable-next-line max-len
import {
  DwFormArray,
  DynamicFormControlComponent,
  DynamicFormControlLayout,
  DynamicFormLayout,
  DynamicFormLayoutService,
  DynamicFormValidationService,
} from '@athena/dynamic-core';
import { DynamicFaultPlanOperateFiledModel } from 'app/implementation/model/fault-plan-operate-filed/fault-plan-operate-filed.model';
import { FaultPlanOperateFiledService } from './fault-plan-operate-filed.service';
import { CommonService } from 'app/implementation/service/common.service';

@Component({
  selector: 'app-fault-plan-operate-filed',
  templateUrl: './fault-plan-operate-filed.component.html',
  styleUrls: ['./fault-plan-operate-filed.component.less'],
  providers: [FaultPlanOperateFiledService, CommonService],
})
export class FaultPlanOperateFiledComponent
  extends DynamicFormControlComponent
  implements OnInit
{
  @Input() formLayout: DynamicFormLayout;
  @Input() group: FormGroup;
  @Input() layout: DynamicFormControlLayout;
  @Input() model: DynamicFaultPlanOperateFiledModel;
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() blur: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() change: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() focus: EventEmitter<any> = new EventEmitter();

  constructor(
    protected changeRef: ChangeDetectorRef,
    protected layoutService: DynamicFormLayoutService,
    protected validationService: DynamicFormValidationService,
    protected elementRef: ElementRef,
    private faultPlanOperateFiledService: FaultPlanOperateFiledService,
    public commonService: CommonService
  ) {
    super(layoutService, validationService, changeRef, elementRef);
  }

  ngOnInit() {
    this.commonService.content = this.model.content;
    console.log('group', this.group.get(''));
  }
  // get disableButton(): boolean {
  //   return this.group.parent.parent.get('review_status').value === 2;
  // }
  get tableList(): any {
    return this.group.parent.parent.get('fault_plan_info_basic_details')[
      '_component'
    ];
  }
  removeRow() {
    /** 表格内操作栏位新增删除定制按钮，点击删除，删除时将该行删除，然后把第一个页签的内容全覆盖至第二个页签，（
     * 若为最后一行则直接删除）
     *  */
    // 若为最后一行则直接删除
    if (this.group.get('sequence').value === this.group.parent.value.length) {
      const lastIndex =
        this.group.parent.parent.get('fault_plan_info_basic_details').value
          .length - 1;
      this.tableList.removeRow(
        (
          (
            this.group.parent.parent.get(
              'fault_plan_info_basic_details'
            ) as DwFormArray
          ).at(lastIndex) as any
        ).uuid
      );
      this.changeRef.markForCheck();
      this.changeRef.detectChanges();
    } else {
      // 删除时将该行删除，删除第二个页签内相同序号的行，将大于该序号的行的序号+1
      // 根据index找uuid
      const deleteIndex = this.group.parent.parent
        .get('fault_plan_info_basic_details')
        .value.findIndex(
          (product) => product.sequence === this.group.get('sequence').value
        );
      // eslint-disable-next-line no-unused-expressions
      this.tableList.removeRow(
        (
          (
            this.group.parent.parent.get(
              'fault_plan_info_basic_details'
            ) as DwFormArray
          ).at(deleteIndex) as any
        ).uuid
      );

      // 且大于该行序号的行序号将进行重新排序，第一第二个页签都需要
      (
        this.group.parent.parent.get(
          'fault_plan_info_basic_details'
        ) as DwFormArray
      ).controls.forEach((control) => {
        const order_seq = control.get('sequence').value;
        if (order_seq > deleteIndex) {
          control.get('sequence').patchValue(order_seq - 1);
        }
      });
    }
    // 标准无法实现，补充逻辑：
    // this.tableList.removeRow(this.group.parent.parent.value.uuid);
  }
  upRow() {
    const upIndex = this.group.parent.parent
      .get('fault_plan_info_basic_details')
      .value.findIndex(
        (product) => product.sequence === this.group.get('sequence').value
      );
    if (upIndex !== 0) {
      console.log('tableList', this.tableList);
      const currentValue = this.tableList['control']['controls'][upIndex].value;
      const preValue = this.tableList['control']['controls'][upIndex - 1].value;
      const tableList = (
        this.group.parent.parent.get(
          'fault_plan_info_basic_details'
        ) as DwFormArray
      ).controls;
      tableList[upIndex].patchValue({
        create_by: preValue.create_by,
        create_date: preValue.create_date,
        creator_name: preValue.creator_name,
        fault_plan_info_basic_details_id:
          preValue.fault_plan_info_basic_details_id,
        fault_plan_info_id: preValue.fault_plan_info_id,
        // tenant_id: preValue.create_by,
        // tenantsid: preValue.create_by,
        edit_type: preValue.edit_type,
        operate: preValue.operate,
        operation: preValue.operation,
        sequence: preValue.sequence,
        value: preValue.value,
        waiting_time: preValue.waiting_time,
        uuid: preValue.uuid,
      });

      tableList[upIndex - 1].patchValue({
        create_by: currentValue.create_by,
        create_date: currentValue.create_date,
        creator_name: currentValue.creator_name,
        fault_plan_info_basic_details_id:
          currentValue.fault_plan_info_basic_details_id,
        fault_plan_info_id: currentValue.fault_plan_info_id,
        // tenant_id: preValue.create_by,
        // tenantsid: preValue.create_by,
        edit_type: currentValue.edit_type,
        operate: currentValue.operate,
        operation: currentValue.operation,
        sequence: currentValue.sequence,
        value: currentValue.value,
        waiting_time: currentValue.waiting_time,
        uuid: currentValue.uuid,
      });
      console.log('upIndex', upIndex);
      tableList[upIndex].get('sequence').patchValue(upIndex + 1);
      tableList[upIndex - 1].get('sequence').patchValue(upIndex);
      this.changeRef.markForCheck();
    }
  }
  downRow() {
    const downIndex = this.group.parent.parent
      .get('fault_plan_info_basic_details')
      .value.findIndex(
        (product) => product.sequence === this.group.get('sequence').value
      );
    if (downIndex !== this.tableList['control'].value.length - 1) {
      console.log('tableList', this.tableList);
      const currentValue =
        this.tableList['control']['controls'][downIndex].value;
      const afterValue =
        this.tableList['control']['controls'][downIndex + 1].value;
      const tableList = (
        this.group.parent.parent.get(
          'fault_plan_info_basic_details'
        ) as DwFormArray
      ).controls;
      tableList[downIndex].patchValue({
        create_by: afterValue.create_by,
        create_date: afterValue.create_date,
        creator_name: afterValue.creator_name,
        fault_plan_info_basic_details_id:
          afterValue.fault_plan_info_basic_details_id,
        fault_plan_info_id: afterValue.fault_plan_info_id,
        edit_type: afterValue.edit_type,
        operate: afterValue.operate,
        operation: afterValue.operation,
        sequence: afterValue.sequence,
        value: afterValue.value,
        waiting_time: afterValue.waiting_time,
        uuid: afterValue.uuid,
      });
      tableList[downIndex + 1].patchValue({
        create_by: currentValue.create_by,
        create_date: currentValue.create_date,
        creator_name: currentValue.creator_name,
        fault_plan_info_basic_details_id:
          currentValue.fault_plan_info_basic_details_id,
        fault_plan_info_id: currentValue.fault_plan_info_id,
        edit_type: currentValue.edit_type,
        operate: currentValue.operate,
        operation: currentValue.operation,
        sequence: currentValue.sequence,
        value: currentValue.value,
        waiting_time: currentValue.waiting_time,
        uuid: currentValue.uuid,
      });
      // console.log('downIndex', downIndex);
      tableList[downIndex].get('sequence').patchValue(downIndex + 1);
      tableList[downIndex + 1].get('sequence').patchValue(downIndex + 2);
      this.changeRef.markForCheck();
    }
  }
}
