import {
  ChangeDetectorRef,
  Component,
  ElementRef,
  EventEmitter,
  Input,
  OnInit,
  Output,
  TemplateRef,
  ViewChild,
} from '@angular/core';
import { FormGroup } from '@angular/forms';
// eslint-disable-next-line max-len
import {
  DynamicFormControlComponent,
  DynamicFormControlLayout,
  DynamicFormLayout,
  DynamicFormLayoutService,
  DynamicFormValidationService,
} from '@athena/dynamic-core';
import { DynamicDeviceDetailModel } from 'app/implementation/model/device-detail/device-detail.model';
import { DeviceDetailService } from './device-detail.service';
import { CommonService } from 'app/implementation/service/common.service';
import { AthGridModalType } from '@athena/design-ui/src/components/modal/modal-types';
import { AthModalService } from '@athena/design-ui/src/components/modal';
@Component({
  selector: 'app-device-detail',
  templateUrl: './device-detail.component.html',
  styleUrls: ['./device-detail.component.less'],
  providers: [DeviceDetailService, CommonService],
})
export class DeviceDetailComponent
  extends DynamicFormControlComponent
  implements OnInit
{
  @Input() formLayout: DynamicFormLayout;
  @Input() group: FormGroup;
  @Input() layout: DynamicFormControlLayout;
  @Input() model: DynamicDeviceDetailModel;
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() blur: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() change: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() focus: EventEmitter<any> = new EventEmitter();
  @ViewChild('deviceDetailTemplateRef')
  deviceDetailTemplateRef: TemplateRef<any>;
  classification_code: any;
  constructor(
    protected changeRef: ChangeDetectorRef,
    protected layoutService: DynamicFormLayoutService,
    protected validationService: DynamicFormValidationService,
    protected elementRef: ElementRef,
    private deviceDetailService: DeviceDetailService,
    public commonService: CommonService,
    public modalService: AthModalService
  ) {
    super(layoutService, validationService, changeRef, elementRef);
  }
  tabsList = ['运行参数', '操作记录', '维修档案'];
  tableList = [];
  operateList = [];
  operateColumnDefs = [
    { headerName: '运行参数', field: 'running_parameter', minWidth: 200 },
    { headerName: '数值', field: 'value', minWidth: 200 },
    { headerName: '单位', field: 'unit', minWidth: 200 },
  ];
  recordList = [];
  recordColumnDefs = [
    { headerName: '操作时间', field: 'operate_time' },
    { headerName: '执行操作', field: 'operation' },
    { headerName: '操作值', field: 'value' },
  ];
  maintenanceList = [];
  maintenanceColumnDefs = [
    { headerName: '保养日期', field: 'actual_finish_datetime' },
    { headerName: '保养类型', field: 'maintenance_type' },
    { headerName: '主修人', field: 'maintenance_worker_name' }, // 拼接 major_person_code+major_person_name
  ];
  showTab = 0;
  shutdown: Boolean;
  classification_name: ''; // 设备类型
  equipment_name: ''; // 设备名称
  workshop: ''; // 车间
  product_line: ''; // 产线
  ngOnInit() {
    this.commonService.content = this.model.content;
    this.shutdown = this.group.get('shutdown').value;
    this.classification_name = this.group.get('classification_name').value;
    this.equipment_name = this.group.get('equipment_name').value;
    this.workshop = this.group.get('workshop').value;
    this.product_line = this.group.get('product_line').value;
    this.classification_code =
      this.group.get('classification_code').value || '';
  }
  getTableList() {
    // 运行参数
    this.deviceDetailService.ca_efm_running_param_info_get({}).then((res) => {
      this.operateList = res;
    });

    // 操作记录
    const operate_record_info = [
      {
        classification_code: this.classification_code,
        equipment_model: this.group.get('equipment_model').value,
        fault_category_code: this.group.get('fault_category_code').value,
        fault_code: this.group.get('fault_code').value,
        plan_version: this.group.get('plan_version').value,
        equipment_fault_info_id: this.group.get('id').value,
      },
    ];
    this.deviceDetailService
      .ca_efm_operate_record_info_get(operate_record_info)
      .then((res) => {
        this.recordList = res;
      });

    // 维修档案 TODO数据中台
    const params = {
      equipment_code: this.group.get('equipment_no').value,
      // equipment_code: 'a2a499d1',
      row_nums: '1000',
    };
    this.commonService
      .maintenanceDmcUrl({
        params,
      })
      .subscribe((res): void => {
        // this.maintenanceList = res.data;
        if (res.data.length) {
          res.data.forEach((item) => {
            const obj = {
              actual_finish_datetime: item.actual_finish_datetime
                ? this.formatDateString(item.actual_finish_datetime)
                : '',
              maintenance_type: item.maintenance_type,
              maintenance_worker_name:
                item.maintenance_worker_name +
                '-' +
                item.maintenance_worker_code,
            };
            this.maintenanceList.push(obj);
          });
        }
      });
  }
  /**
   * 格式化时间
   * @param dateString
   * @returns
   */
  formatDateString(dateString) {
    // 创建一个 Date 对象
    const date = new Date(dateString);
    // 获取年、月、日、时、分、秒
    const year = date.getFullYear();
    const month = String(date.getMonth() + 1).padStart(2, '0'); // 月份是从0开始的，所以需要加1
    const day = String(date.getDate()).padStart(2, '0');
    const hours = String(date.getHours()).padStart(2, '0');
    const minutes = String(date.getMinutes()).padStart(2, '0');
    const seconds = String(date.getSeconds()).padStart(2, '0');
    // 格式化为 YY/MM/DD hh:mm:ss
    const formattedDate = `${year
      .toString()
      .slice(-2)}/${month}/${day} ${hours}:${minutes}:${seconds}`;
    return formattedDate;
  }
  openModal(columns: number, modalType: AthGridModalType) {
    this.getTableList();
    this.showTab = 1;
    return this.modalService.create({
      nzTitle: '设备详情',
      nzWrapClassName: 'ath-grid-modal-wrap',
      nzContent: this.deviceDetailTemplateRef,
      nzComponentParams: {
        span: columns,
        modalType: modalType,
      },
      gridConfig: {
        span: columns,
        modalType: modalType,
      },
      nzOnCancel: (): void => {},
    });
  }
  clickTab(index) {
    this.showTab = index + 1;
  }
}
