import {
  ChangeDetectorRef,
  Component,
  ElementRef,
  EventEmitter,
  Input,
  OnInit,
  Output,
  TemplateRef,
  ViewChild,
} from '@angular/core';
import { FormGroup } from '@angular/forms';
// eslint-disable-next-line max-len
import {
  DynamicFormControlComponent,
  DynamicFormControlLayout,
  DynamicFormLayout,
  DynamicFormLayoutService,
  DynamicFormService,
  DynamicFormValidationService,
} from '@athena/dynamic-core';
import { DynamicDispatchListModel } from 'app/implementation/model/dispatch-list/dispatch-list.model';
import { DispatchListService } from './dispatch-list.service';
import { CommonService } from 'app/implementation/service/common.service';
import { AthGridModalType } from '@athena/design-ui/components/modal/modal-types';
import { AthModalService } from '@athena/design-ui/src/components/modal';
import column from './column';

@Component({
  selector: 'app-dispatch-list',
  templateUrl: './dispatch-list.component.html',
  styleUrls: ['./dispatch-list.component.less'],
  providers: [DispatchListService],
})
export class DispatchListComponent
  extends DynamicFormControlComponent
  implements OnInit
{
  @Input() formLayout: DynamicFormLayout;
  @Input() group: FormGroup;
  @Input() layout: DynamicFormControlLayout;
  @Input() model: DynamicDispatchListModel;
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() blur: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() change: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() focus: EventEmitter<any> = new EventEmitter();
  @ViewChild('dispatchListTemplateRef')
  dispatchListTemplateRef: TemplateRef<any>;
  formGroup: FormGroup;
  tableList = [];
  pageCode: any;
  flag = true;
  constructor(
    protected changeRef: ChangeDetectorRef,
    protected layoutService: DynamicFormLayoutService,
    protected validationService: DynamicFormValidationService,
    protected elementRef: ElementRef,
    private dispatchListService: DispatchListService,
    public commonService: CommonService,
    public modalService: AthModalService,
    public formService: DynamicFormService
  ) {
    super(layoutService, validationService, changeRef, elementRef);
  }

  ngOnInit() {
    this.commonService.content = this.model.content;
    this.pageCode = this.commonService.content.pageCode;

    this.commonService.messageSource.subscribe((message) => {
      if (message === true) {
        // debugger;
        this.getTableList();
        // this.modalService.closeAll();
        // this.change.emit({
        //   type: 'application-submit',
        // });
        // this.changeRef.markForCheck();
      }
    });
    // console.log('group', this.group.value);
  }
  // eslint-disable-next-line @angular-eslint/use-lifecycle-interface
  ngOnDestroy(): void {
    // this.commonService.messageSource.unsubscribe();
    // this.commonService.messageSource.complete();
  }
  openModal(columns: number, modalType: AthGridModalType) {
    this.getTableList();

    sessionStorage.setItem(
      'equipment_fault_info',
      JSON.stringify(this.group.value)
    );

    return this.modalService.create({
      nzTitle: '派遣清单',
      nzWrapClassName: 'ath-grid-modal-wrap',
      nzContent: this.dispatchListTemplateRef,
      nzComponentParams: {
        span: columns,
        modalType: modalType,
        equipment_fault_info: this.group.value,
      },
      gridConfig: {
        span: columns,
        modalType: modalType,
      },
      nzOnCancel: (): void => {},
      // eslint-disable-next-line no-shadow
      nzOnOk: (EventEmitter: any): Boolean => {
        this.change.emit({
          type: 'application-submit',
        });
        this.changeRef.markForCheck();
        return true;
      },
    });
  }
  getTableList() {
    this.tableList = [];
    const trans_task_info = [
      {
        equipment_fault_info_id: this.group.get('id').value,
      },
    ];
    this.dispatchListService
      .ca_efm_trans_task_info_get(trans_task_info)
      .then((res) => {
        this.tableList = res;
        // this.flag = true;
        this.initTable();
        // console.log('tableList', this.tableList);
      });
  }
  initTable() {
    const source = this.createDynamicTableJSON();
    source.layout = Array.isArray(source?.layout) ? source.layout : [];
    const initializedData = this.formService.initData(
      source.layout as any,
      source.pageData,
      source.rules as any,
      source.style
    );
    // this.formLayout = initializedData.formLayout; // 样式
    this.formModel = initializedData.formModel; // 组件数据模型
    this.formGroup = initializedData.formGroup; // formGroup
    //  this.group = initializedData.formGroup; // formGroup
  }

  createDynamicTableJSON() {
    const data = {
      layout: [
        {
          id: 'trans_task_info',
          type: 'ATHENA_TABLE',
          editable: true,
          disabledUserDefined: true,
          schema: 'trans_task_info',
          scriptFilters: [],
          setting: {
            hideDefaultToolbar: ['composite-sort', 'setting'],
          },
          columnDefs: this.getColumn(),
          allFields: [],
        },
      ],
      pageData: {
        trans_task_info: this.tableList,
      },
      rules: [
        {
          schema: 'occupied_state',
          path: 'trans_task_info',
          validatorType: 'warning',
          errorMessage: '',
          trigger: {
            condition:
              "data.occupied_state==='3'?'blue':(data.occupied_state==='1'?'green':'red')",
            point: 'default',
            type: 'sync',
          },
          key: 'style',
          crossFieldOrNot: false,
        },
      ],
      content: {},
      style: {},
    };
    return data;
  }
  getColumn() {
    const materialcolums = JSON.parse(JSON.stringify(column));
    // eslint-disable-next-line no-shadow
    const res = materialcolums.map((column) => {
      return {
        ...column,
      };
    });
    return res;
  }
}
