import {
  ChangeDetectorRef,
  Component,
  ElementRef,
  EventEmitter,
  Input,
  OnInit,
  Output,
  TemplateRef,
  ViewChild,
} from '@angular/core';
import { FormGroup } from '@angular/forms';
// eslint-disable-next-line max-len
import {
  DynamicFormControlComponent,
  DynamicFormControlLayout,
  DynamicFormLayout,
  DynamicFormLayoutService,
  DynamicFormService,
  DynamicFormValidationService,
} from '@athena/dynamic-core';
import { DynamicFaultCountModel } from 'app/implementation/model/fault-count/fault-count.model';
import { FaultCountService } from './fault-count.service';
import { CommonService } from 'app/implementation/service/common.service';
import { AthGridModalType } from '@athena/design-ui/src/components/modal/modal-types';
import { AthModalService } from '@athena/design-ui/src/components/modal';
import column from './column';
@Component({
  selector: 'app-fault-count',
  templateUrl: './fault-count.component.html',
  styleUrls: ['./fault-count.component.less'],
  providers: [FaultCountService, CommonService],
})
export class FaultCountComponent
  extends DynamicFormControlComponent
  implements OnInit
{
  @Input() formLayout: DynamicFormLayout;
  @Input() group: FormGroup;
  @Input() layout: DynamicFormControlLayout;
  @Input() model: DynamicFaultCountModel;
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() blur: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() change: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() focus: EventEmitter<any> = new EventEmitter();
  @ViewChild('faultCountTemplateRef') faultCountTemplateRef: TemplateRef<any>;
  formGroup: FormGroup;
  falutList = [];
  year: number;
  month: number;
  constructor(
    protected changeRef: ChangeDetectorRef,
    protected layoutService: DynamicFormLayoutService,
    protected validationService: DynamicFormValidationService,
    protected elementRef: ElementRef,
    private faultCountService: FaultCountService,
    public modalService: AthModalService,
    public formService: DynamicFormService,
    public commonService: CommonService
  ) {
    super(layoutService, validationService, changeRef, elementRef);
  }

  ngOnInit() {
    this.commonService.content = this.model.content;
    const dateString = this.group.get('report_time').value;
    if (dateString) {
      const result = this.getPreviousMonthYearMonth(dateString);
      this.year = result.year;
      this.month = result.month;
    }
  }

  openModal(columns: number, modalType: AthGridModalType) {
    sessionStorage.setItem(
      'equipment_fault_info1',
      JSON.stringify(this.group.value)
    );
    this.getTableList();

    return this.modalService.create({
      nzTitle: '故障统计',
      nzWrapClassName: 'ath-grid-modal-wrap',
      nzContent: this.faultCountTemplateRef,
      nzComponentParams: {
        span: columns,
        modalType: modalType,
      },
      gridConfig: {
        span: columns,
        modalType: modalType,
      },
      nzOnCancel: (): void => {},
    });
  }
  initTable() {
    const source = this.createDynamicTableJSON();
    source.layout = Array.isArray(source?.layout) ? source.layout : [];
    const initializedData = this.formService.initData(
      source.layout as any,
      source.pageData,
      source.rules as any,
      source.style
    );
    // this.formLayout = initializedData.formLayout; // 样式
    this.formModel = initializedData.formModel; // 组件数据模型
    this.formGroup = initializedData.formGroup; // formGroup
    //  this.group = initializedData.formGroup; // formGroup
  }
  createDynamicTableJSON() {
    const data = {
      layout: [
        {
          id: 'equipment_fault_info.trans_task_info',
          type: 'ATHENA_TABLE',
          editable: true,
          disabledUserDefined: true,
          schema: 'equipment_fault_info.trans_task_info',
          scriptFilters: [],
          setting: {
            hideDefaultToolbar: ['composite-sort', 'setting'],
          },
          columnDefs: this.getColumn(),
          allFields: [],
        },
      ],
      pageData: {
        equipment_fault_info: {
          trans_task_info: this.falutList,
        },
      },
      rules: [],
      content: {},
      style: {},
    };
    return data;
  }
  getColumn() {
    const materialcolums = JSON.parse(JSON.stringify(column));
    // eslint-disable-next-line no-shadow
    const res = materialcolums.map((column) => {
      return {
        ...column,
      };
    });
    return res;
  }
  getTableList() {
    // 入参：年份(year)、月份(month为当前故障发生时间所在年月-1)、设备编号(equipment_code)
    // TODO数据中台
    const params = {
      equipment_code: this.group.get('equipment_no').value,
      // equipment_code: 'a2a499d1',
      year: this.year.toString(),
      month: this.month.toString(),
    };
    this.commonService.faultCountDmcUrl({ params }).subscribe((res): void => {
      this.falutList = res.data;
      this.falutList.forEach((item) => {
        item.failure_name = item.failure_name + '-' + item.failure_code;
      });
      this.initTable();
    });
  }
  /**
   * 获取年份、月份
   */
  getPreviousMonthYearMonth(dateString) {
    const date = new Date(dateString);
    const year = date.getFullYear();
    const month = date.getMonth(); // 注意：月份是从0开始的，需要加1才能得到正常的月份数字

    const previousMonth = month - 1;
    const previousYear = previousMonth === -1 ? year - 1 : year; // 如果上个月是12月则年份减1
    const previousMonthNumber = previousMonth === -1 ? 12 : previousMonth + 1;

    return {
      year: previousYear,
      month: previousMonthNumber,
    };
  }
}
