import {
  ChangeDetectorRef,
  Component,
  ElementRef,
  EventEmitter,
  Input,
  OnInit,
  Output,
  TemplateRef,
  ViewChild,
} from '@angular/core';
import { FormGroup } from '@angular/forms';
// eslint-disable-next-line max-len
import {
  DynamicFormControlComponent,
  DynamicFormControlLayout,
  DynamicFormLayout,
  DynamicFormLayoutService,
  DynamicFormValidationService,
} from '@athena/dynamic-core';
import { DynamicFaultDetailBtnModel } from 'app/implementation/model/fault-detail-btn/fault-detail-btn.model';
import { FaultDetailBtnService } from './fault-detail-btn.service';
import { CommonService } from 'app/implementation/service/common.service';
import { AthGridModalType } from '@athena/design-ui/src/components/modal/modal-types';
import { AthModalService } from '@athena/design-ui/src/components/modal';

@Component({
  selector: 'app-fault-detail-btn',
  templateUrl: './fault-detail-btn.component.html',
  styleUrls: ['./fault-detail-btn.component.less'],
  providers: [FaultDetailBtnService, CommonService],
})
export class FaultDetailBtnComponent
  extends DynamicFormControlComponent
  implements OnInit
{
  @Input() formLayout: DynamicFormLayout;
  @Input() group: FormGroup;
  @Input() layout: DynamicFormControlLayout;
  @Input() model: DynamicFaultDetailBtnModel;
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() blur: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() change: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() focus: EventEmitter<any> = new EventEmitter();
  @ViewChild('faultDetailTemplateRef') faultDetailTemplateRef: TemplateRef<any>;
  faultDetailList = [];
  faultDetailColumnDefs = [
    { headerName: '故障发生时间', field: 'failure_datetime' },
    { headerName: '故障分类', field: 'failure_category_name' },
    { headerName: '故障码', field: 'failure_name' }, // 拼接code
    { headerName: '故障现象', field: 'failure_phenomenon' },
    { headerName: '故障原因', field: 'failure_reason' },
    { headerName: '故障部件', field: 'failure_parts' }, // 拼接code
    { headerName: '处理经过', field: 'handling_process' },
    { headerName: '处理人', field: 'exclude_failure_staff_name' }, // 拼接code
    { headerName: '故障解决时间', field: 'exclude_failure_datetime' }, // 拼接code
  ];
  equipment_fault_info: any;
  constructor(
    protected changeRef: ChangeDetectorRef,
    protected layoutService: DynamicFormLayoutService,
    protected validationService: DynamicFormValidationService,
    protected elementRef: ElementRef,
    private faultDetailBtnService: FaultDetailBtnService,
    public modalService: AthModalService,
    public commonService: CommonService
  ) {
    super(layoutService, validationService, changeRef, elementRef);
  }
  firstDay: string;
  lastDay: string;
  ngOnInit() {
    this.commonService.content = this.model.content;
    // console.log('group--故障明细', this.group);
    // 获取故障上报时间
    const equipment_fault_info = sessionStorage.getItem(
      'equipment_fault_info1'
    );
    this.equipment_fault_info = JSON.parse(equipment_fault_info);
    const dateString = this.equipment_fault_info.report_time;
    if (dateString) {
      const result = this.getPreviousMonthRange(dateString);
      this.firstDay = result.firstDay;
      this.lastDay = result.lastDay;
    }
  }
  formatDateString(dateString) {
    // 创建一个 Date 对象
    const date = new Date(dateString);
    // 获取年、月、日、时、分、秒
    const year = date.getFullYear();
    const month = String(date.getMonth() + 1).padStart(2, '0'); // 月份是从0开始的，所以需要加1
    const day = String(date.getDate()).padStart(2, '0');
    const hours = String(date.getHours()).padStart(2, '0');
    const minutes = String(date.getMinutes()).padStart(2, '0');
    const seconds = String(date.getSeconds()).padStart(2, '0');
    // 格式化为 YY/MM/DD hh:mm:ss
    const formattedDate = `${year
      .toString()
      .slice(-2)}/${month}/${day} ${hours}:${minutes}:${seconds}`;
    return formattedDate;
  }
  openModal(columns: number, modalType: AthGridModalType) {
    this.getTableList();
    return this.modalService.create({
      nzTitle: '当前生产计划',
      nzWrapClassName: 'ath-grid-modal-wrap',
      nzContent: this.faultDetailTemplateRef,
      nzComponentParams: {
        span: columns,
        modalType: modalType,
      },
      gridConfig: {
        span: columns,
        modalType: modalType,
      },
      nzOnCancel: (): void => {},
    });
  }
  getTableList() {
    // 入参：年份(year)、月份(month为当前故障发生时间所在年月-1)、设备编号(equipment_code)
    // TODO数据中台

    const params = {
      equipment_code: this.group.get('equipment_code').value,
      // equipment_code: '65eb49eb',
      failure_datetime_start: this.firstDay,
      failure_datetime_end: this.lastDay,
    };
    this.commonService
      .faultCountDetailDmcUrl({ params })
      .subscribe((res): void => {
        // this.faultDetailList = res.data;
        if (res.data.length) {
          res.data.forEach((item) => {
            item.failure_datetime = item.failure_datetime
              ? this.formatDateString(item.failure_datetime)
              : '';
            item.exclude_failure_datetime = item.exclude_failure_datetime
              ? this.formatDateString(item.exclude_failure_datetime)
              : '';
            item.failure_name = item.failure_name + '-' + item.failure_code;
            item.exclude_failure_staff_name =
              item.exclude_failure_staff_name +
              '-' +
              item.exclude_failure_staff_code;
          });
          this.faultDetailList = res.data;
        }
      });
  }
  formatDate(date) {
    const year = date.getFullYear();
    const month = String(date.getMonth() + 1).padStart(2, '0'); // 月份从0开始，需要+1并补零
    const day = String(date.getDate()).padStart(2, '0');
    const hours = String(date.getHours()).padStart(2, '0');
    const minutes = String(date.getMinutes()).padStart(2, '0');
    const seconds = String(date.getSeconds()).padStart(2, '0');
    return `${year}-${month}-${day} ${hours}:${minutes}:${seconds}`;
  }

  getPreviousMonthRange(dateString) {
    const date = new Date(dateString);
    const year = date.getFullYear();
    const month = date.getMonth();
    const firstDayLastMonth = new Date(year, month - 1, 1);
    const lastDayLastMonth = new Date(year, month, 0);
    return {
      firstDay: this.formatDate(firstDayLastMonth),
      lastDay: this.formatDate(lastDayLastMonth),
    };
  }
}
