import { menuData } from './../../../menu/model/menu.model';
import {
  ChangeDetectorRef,
  Component,
  ElementRef,
  EventEmitter,
  Input,
  OnInit,
  Output,
  TemplateRef,
  ViewChild,
} from '@angular/core';
import { FormGroup } from '@angular/forms';
// eslint-disable-next-line max-len
import {
  DynamicFormControlComponent,
  DynamicFormControlLayout,
  DynamicFormLayout,
  DynamicFormLayoutService,
  DynamicFormService,
  DynamicFormValidationService,
} from '@athena/dynamic-core';
import { DynamicKnowledgeBaseModel } from 'app/implementation/model/knowledge-base/knowledge-base.model';
import { KnowledgeBaseService } from './knowledge-base.service';
import { CommonService } from 'app/implementation/service/common.service';
import { AthGridModalType } from '@athena/design-ui/src/components/modal/modal-types';
import { AthModalService } from '@athena/design-ui/src/components/modal';

@Component({
  selector: 'app-knowledge-base',
  templateUrl: './knowledge-base.component.html',
  styleUrls: ['./knowledge-base.component.less'],
  providers: [KnowledgeBaseService, CommonService],
})
export class KnowledgeBaseComponent
  extends DynamicFormControlComponent
  implements OnInit
{
  @Input() formLayout: DynamicFormLayout;
  @Input() group: FormGroup;
  @Input() layout: DynamicFormControlLayout;
  @Input() model: DynamicKnowledgeBaseModel;
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() blur: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() change: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() focus: EventEmitter<any> = new EventEmitter();
  @ViewChild('knowledgeTemplateRef') knowledgeTemplateRef: TemplateRef<any>;
  failure_parts = '';
  failure_phenomenon = '';
  columnDefs: any[] = [
    { headerName: '故障部件', field: 'failure_parts' },
    { headerName: '故障现象', field: 'failure_phenomenon' },
    { headerName: '故障原因', field: 'failure_reason' },
    { headerName: '故障处理措施', field: 'handling_measures' },
    { headerName: '备注', field: 'remarks' },
  ];
  tableList = [];
  equipment_model: any;
  equipment_name: any;
  fault_category_name: any;
  fault_code: any;
  equipment_type: any;
  selectData: any = {};
  constructor(
    protected changeRef: ChangeDetectorRef,
    protected layoutService: DynamicFormLayoutService,
    protected validationService: DynamicFormValidationService,
    protected elementRef: ElementRef,
    private knowledgeBaseService: KnowledgeBaseService,
    public modalService: AthModalService,
    public formService: DynamicFormService,
    public commonService: CommonService
  ) {
    super(layoutService, validationService, changeRef, elementRef);
  }

  ngOnInit() {
    this.commonService.content = this.model.content;
    // console.log('group', this.group.value['handling_info'][0]);
    // 一条任务卡一条数据
    const group = this.group.value['handling_info'];
    this.equipment_model = group.equipment_model;
    this.equipment_name = group.equipment_name;
    this.fault_category_name = group.fault_category_name;
    this.fault_code = group.fault_code;
    this.equipment_type = group.classification_name; // 设备分类
  }
  openModal(columns: number, modalType: AthGridModalType) {
    return this.modalService.create({
      nzTitle: '知识库',
      nzWrapClassName: 'ath-grid-modal-wrap',
      nzContent: this.knowledgeTemplateRef,
      nzComponentParams: {
        span: columns,
        modalType: modalType,
      },
      gridConfig: {
        span: columns,
        modalType: modalType,
      },
      nzOnCancel: (): void => {},
      nzOnOk: (EventEmitter: any): Boolean => {
        if (this.selectData) {
          // 将故障原因、问题部件、处理方案带回页面
          const failure_reason = this.selectData.failure_reason || '';
          const handling_measures = this.selectData.handling_measures || '';
          const failure_parts = this.selectData.failure_parts || '';
          // 故障原因
          this.group.controls['handling_info']
            .get('fault_reason')
            .patchValue(failure_reason);
          // 问题部件
          this.group.controls['handling_info']
            .get('fault_parts')
            .patchValue(failure_parts);
          // 处理方案
          this.group.controls['handling_info']
            .get('fault_action')
            .patchValue(handling_measures);
        }
        return true;
      },
    });
  }
  getTableList() {
    // 入参：设备分类equipment_type 、故障部件failure_parts like 、故障现象failure_phenomenon like、
    const params = {
      // equipment_type: '加工自动线',
      // failure_parts: '机械臂',
      // failure_phenomenon: '异常',

      equipment_type: this.equipment_type,
      failure_parts: this.failure_parts,
      failure_phenomenon: this.failure_phenomenon,
    };
    this.commonService
      .knowledgeBaseDmcUrl({
        params,
      })
      .subscribe((res): void => {
        this.tableList = res.data;
      });
  }
  rowSelected(event) {
    console.log('event', event);
    this.selectData = event.data;
    console.log('group', this.group);
    // node.setDataValue('uibot_checked', node.selected);
  }
}
