/* eslint-disable no-shadow */
import {
  ChangeDetectorRef,
  Component,
  ElementRef,
  EventEmitter,
  Input,
  OnInit,
  Output,
  TemplateRef,
  ViewChild,
} from '@angular/core';
import { FormGroup } from '@angular/forms';
// eslint-disable-next-line max-len
import {
  DynamicFormControlComponent,
  DynamicFormControlLayout,
  DynamicFormLayout,
  DynamicFormLayoutService,
  DynamicFormValidationService,
} from '@athena/dynamic-core';
import { DynamicSettingBtnModel } from 'app/implementation/model/setting-btn/setting-btn.model';
import { SettingBtnService } from './setting-btn.service';
import { CommonService } from 'app/implementation/service/common.service';
import { AthGridModalType } from '@athena/design-ui/src/components/modal/modal-types';
import { AthModalService } from '@athena/design-ui/src/components/modal';
import { setTimeout } from 'timers';

@Component({
  selector: 'app-setting-btn',
  templateUrl: './setting-btn.component.html',
  styleUrls: ['./setting-btn.component.less'],
  providers: [SettingBtnService],
})
export class SettingBtnComponent
  extends DynamicFormControlComponent
  implements OnInit
{
  @Input() formLayout: DynamicFormLayout;
  @Input() group: FormGroup;
  @Input() layout: DynamicFormControlLayout;
  @Input() model: DynamicSettingBtnModel;
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() blur: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() change: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() focus: EventEmitter<any> = new EventEmitter();
  // 设置负责人
  @ViewChild('setPersonTemplateRef') setPersonTemplateRef: TemplateRef<any>;
  @ViewChild('setPersonTemplateRef1') setPersonTemplateRef1: TemplateRef<any>;
  // occupiedTemplateRef 加派
  @ViewChild('occupiedTemplateRef') occupiedTemplateRef: TemplateRef<any>;
  // withDrawTemplateRef 撤回
  @ViewChild('withDrawTemplateRef') withDrawTemplateRef: TemplateRef<any>;
  // priorityTemplateRef
  @ViewChild('priorityTemplateRef') priorityTemplateRef: TemplateRef<any>;
  is_responsible: any; // 是否为负责人
  occupied_state: any; // 是否已派遣 1（已派遣），2（占用中），3（空闲中）
  have_person: Boolean = true; // 当前列表是否存在负责人
  priority_type = ''; // 任务占用选择优先级
  status = '1'; // 故障派遣处理状态=2，全部隐藏
  equipment_fault_info: any;
  constructor(
    protected changeRef: ChangeDetectorRef,
    protected layoutService: DynamicFormLayoutService,
    protected validationService: DynamicFormValidationService,
    protected elementRef: ElementRef,
    private settingBtnService: SettingBtnService,
    public commonService: CommonService,
    public modalService: AthModalService
  ) {
    super(layoutService, validationService, changeRef, elementRef);
  }

  ngOnInit() {
    this.commonService.content = this.model.content;
    // 获取当前列表是否存在负责人；TODO
    // console.log('status', this.commonService.content);
    this.have_person = this.group.parent.value[0].is_responsible;
    this.is_responsible = this.group.get('is_responsible').value;
    this.occupied_state = this.group.get('occupied_state').value;
    // console.log('group-按钮', this.group.value);
    const equipment_fault_info = sessionStorage.getItem('equipment_fault_info');
    this.equipment_fault_info = JSON.parse(equipment_fault_info);
    // console.log('equipment_fault_info', this.equipment_fault_info);
    this.status = this.equipment_fault_info.status;
  }

  /**
   * 加派
   * @param columns
   * @param modalType
   * @param type
   * @returns
   */
  openPersonModal(columns: number, modalType: AthGridModalType, type) {
    if (this.have_person === false) {
      // 不存在责任人
      this.settingPerson();
    } else if (this.have_person === true) {
      // 情况1: 存在责任人，且被占用
      return this.modalService.create({
        nzTitle: '故障已指定责任人，是否更换责任人？',
        nzWrapClassName: 'ath-grid-modal-wrap',
        nzContent: this.setPersonTemplateRef1,
        nzComponentParams: {
          span: columns,
          modalType: modalType,
        },
        gridConfig: {
          span: columns,
          modalType: modalType,
        },
        nzOnCancel: (): void => {},
        nzOnOk: (EventEmitter: any): Boolean => {
          // 当前条目被占用
          if (this.occupied_state === '2') {
            this.openPriorityModal(8, 'form-modal', type);
          } else {
            // 当前条目未被专用
            this.settingPerson();
          }
          return true;
        },
      });
    }
    // else if (this.have_person === true && this.occupied_state === '3') {
    //   // 情况2:存在负责人且当前人员空闲，是否替换责任人
    //   return this.modalService.create({
    //     nzTitle: '故障已指定责任人，是否更换责任人？',
    //     nzWrapClassName: 'ath-grid-modal-wrap',
    //     nzContent: this.setPersonTemplateRef,
    //     nzComponentParams: {
    //       span: columns,
    //       modalType: modalType,
    //     },
    //     gridConfig: {
    //       span: columns,
    //       modalType: modalType,
    //     },
    //     nzOnCancel: (): void => {},
    //     nzOnOk: (EventEmitter: any): Boolean => {
    //       switch (type) {
    //         case 1: // 设置责任人
    //           this.settingPerson();
    //           break;
    //         case 2: // 加派辅助
    //           this.settingDispatch();
    //           break;
    //       }
    //       // this.change.emit({
    //       //   type: 'application-submit',
    //       // });
    //       // this.changeRef.markForCheck();
    //       return true;
    //     },
    //   });
    // } else if (this.have_person === false && this.occupied_state === '2') {
    //   // 情况3:不存在负责人并且当前人员不空闲，则先选择优先级
    //   const model = this.openPriorityModal(8, 'form-modal', type);
    // } else if (this.have_person === false && this.occupied_state !== '2') {
    //   // 情况4: 不存在负责人并且当前人员不被占用
    //   // 直接调用设置负责人的接口
    //   switch (type) {
    //     case 1: // 设置责任人
    //       this.settingPerson();
    //       break;
    //     case 2: // 加派辅助
    //       this.settingDispatch();
    //       break;
    //   }
    // }
  }
  openDispatchModal(columns: number, modalType: AthGridModalType, type) {
    if (this.have_person === false) {
      // 不存在责任人
      return this.modalService.create({
        nzTitle: '故障尚无处理责任人，请先指定责任人！',
        nzWrapClassName: 'ath-grid-modal-wrap',
        nzContent: this.setPersonTemplateRef1,
        nzComponentParams: {
          span: columns,
          modalType: modalType,
        },
        gridConfig: {
          span: columns,
          modalType: modalType,
        },
        nzOnCancel: (): void => {},
        nzOnOk: (EventEmitter: any): Boolean => {
          return true;
        },
      });
    } else if (this.have_person === true) {
      // 情况1: 存在责任人，且被占用
      // 当前条目被占用
      if (this.occupied_state === '2') {
        this.openPriorityModal(8, 'form-modal', type);
      } else {
        // 当前条目未被占用
        this.settingDispatch();
      }
    }
    // else if (this.have_person === true && this.occupied_state === '3') {
    //   // 情况2:存在负责人且当前人员空闲，是否替换责任人
    //   return this.modalService.create({
    //     nzTitle: '故障已指定责任人，是否更换责任人？',
    //     nzWrapClassName: 'ath-grid-modal-wrap',
    //     nzContent: this.setPersonTemplateRef,
    //     nzComponentParams: {
    //       span: columns,
    //       modalType: modalType,
    //     },
    //     gridConfig: {
    //       span: columns,
    //       modalType: modalType,
    //     },
    //     nzOnCancel: (): void => {},
    //     nzOnOk: (EventEmitter: any): Boolean => {
    //       switch (type) {
    //         case 1: // 设置责任人
    //           this.settingPerson();
    //           break;
    //         case 2: // 加派辅助
    //           this.settingDispatch();
    //           break;
    //       }
    //       // this.change.emit({
    //       //   type: 'application-submit',
    //       // });
    //       // this.changeRef.markForCheck();
    //       return true;
    //     },
    //   });
    // } else if (this.have_person === false && this.occupied_state === '2') {
    //   // 情况3:不存在负责人并且当前人员不空闲，则先选择优先级
    //   const model = this.openPriorityModal(8, 'form-modal', type);
    // } else if (this.have_person === false && this.occupied_state !== '2') {
    //   // 情况4: 不存在负责人并且当前人员不被占用
    //   // 直接调用设置负责人的接口
    //   switch (type) {
    //     case 1: // 设置责任人
    //       this.settingPerson();
    //       break;
    //     case 2: // 加派辅助
    //       this.settingDispatch();
    //       break;
    //   }
    // }
  }
  openPriorityModal(columns: number, modalType: AthGridModalType, type) {
    const model = this.modalService.create({
      nzTitle: '该人员目前正在执行其他任务，请确认优先级！',
      nzWrapClassName: 'ath-grid-modal-wrap',
      nzContent: this.priorityTemplateRef,
      nzComponentParams: {
        span: columns,
        modalType: modalType,
      },
      gridConfig: {
        span: columns,
        modalType: modalType,
      },
      nzFooter: [
        {
          label: '原任务优先', // 按钮文本
          type: 'primary',
          onClick: (e) => {
            this.priority_type = '1';
            switch (type) {
              case 1:
                // 设置责任人
                this.settingPerson();
                break;
              case 2:
                // 加派辅助
                this.settingDispatch();
                break;
            }
            model.close();
            // this.modalService.closeAll();
            // this.change.emit({
            //   type: 'application-submit',
            // });
            // this.changeRef.markForCheck();
          },
        },
        {
          label: '当前任务优先', // 按钮文本
          type: 'primary',
          onClick: (e) => {
            this.priority_type = '2';
            switch (type) {
              case 1:
                this.settingPerson();
                break;
              case 2:
                this.settingDispatch();
                break;
            }
            // this.modalService.closeAll();
            // this.change.emit({
            //   type: 'application-submit',
            // });
            // this.changeRef.markForCheck();
            model.close();
          },
        },
        {
          label: '返回重新选择', // 按钮文本
          type: 'primary',
          onClick: (e) => {
            this.priority_type = '';
            model.close();
          },
        },
      ],
    });

    return model;
  }
  /**
   *  调用设置负责人的接口
   */
  settingPerson() {
    // // 调用更换责任人的接口。TODO需调整入参，传入任务卡当前条目的全部数据
    const charge_info = [
      {
        id: this.group.get('id').value || '',
        eoc_no: this.group.get('eoc_no').value,
        eoc_name: this.group.get('eoc_name').value,
        priority: this.priority_type,
        is_responsible: this.have_person,
        equipment_fault_info: this.equipment_fault_info,
        activity_backLog_datas:
          this.equipment_fault_info.activity__backLog__data,
      },
    ];
    this.settingBtnService
      .ca_efm_set_charge_info_process(charge_info)
      .then((res) => {
        this.commonService.messageSource.next(true);
        // 更新数据，是否重新调用get接口
        // this.getTableList();
      });
  }
  /**
   * 调用加派辅助的接口
   */
  settingDispatch() {
    // // 调用加派辅助的接口
    const charge_info = [
      {
        id: this.group.get('id').value || '',
        eoc_no: this.group.get('eoc_no').value,
        eoc_name: this.group.get('eoc_name').value,
        priority: this.priority_type,
        is_responsible: this.have_person,
        equipment_fault_info: this.equipment_fault_info,
        activity_backLog_datas:
          this.equipment_fault_info.activity__backLog__data,
      },
    ];
    this.settingBtnService
      .ca_efm_add_dispat_info_process(charge_info)
      .then((res) => {
        this.commonService.messageSource.next(true);
        // 更新数据，是否重新调用get接口
      });
  }
  // 撤回
  openWithDrawModal(columns: number, modalType: AthGridModalType) {
    return this.modalService.create({
      nzTitle: '确认撤回？',
      nzWrapClassName: 'ath-grid-modal-wrap',
      nzContent: this.withDrawTemplateRef,
      nzComponentParams: {
        span: columns,
        modalType: modalType,
      },
      gridConfig: {
        span: columns,
        modalType: modalType,
      },
      nzOnCancel: (): void => {},
      nzOnOk: (EventEmitter: any): Boolean => {
        const revocation_info = [
          {
            id: this.group.get('id').value,
          },
        ];
        this.settingBtnService
          .ca_efm_revocation_info_process(revocation_info)
          .then((res) => {
            this.commonService.messageSource.next(true);
            // if (res) {
            //   // 重新调用get
            //   const trans_task_info = [
            //     {
            //       equipment_fault_info_id: this.group.get(
            //         'equipment_fault_info_id'
            //       ).value,
            //     },
            //   ];
            //   this.settingBtnService
            //     .ca_efm_trans_task_info_get(trans_task_info)
            //     .then((res) => {
            //       // 获取表格数据，更新表格数据
            //       // this.tableList = res;
            //     });
            // }
          });

        return true;
      },
    });
  }
  /**
   * 获取列表
   */
  getTableList() {
    const trans_task_info = [
      {
        equipment_fault_info_id: this.equipment_fault_info.id,
      },
    ];
    this.settingBtnService
      .ca_efm_trans_task_info_get(trans_task_info)
      .then((res) => {
        // console.log('tableList', this.tableList);
        // this.group.parent.setTableData([])
      });
  }
}
