import {
  ChangeDetectorRef,
  Component,
  ElementRef,
  EventEmitter,
  Input,
  OnInit,
  Output,
  TemplateRef,
  ViewChild,
} from '@angular/core';
import { FormGroup } from '@angular/forms';
// eslint-disable-next-line max-len
import {
  DynamicFormControlComponent,
  DynamicFormControlLayout,
  DynamicFormLayout,
  DynamicFormLayoutService,
  DynamicFormValidationService,
} from '@athena/dynamic-core';
import { DynamicTimeExpandModel } from 'app/implementation/model/time-expand/time-expand.model';
import { TimeExpandService } from './time-expand.service';
import { CommonService } from 'app/implementation/service/common.service';
import { AthGridModalType } from '@athena/design-ui/components/modal/modal-types';
import { AthModalService } from '@athena/design-ui/src/components/modal';

@Component({
  selector: 'app-time-expand',
  templateUrl: './time-expand.component.html',
  styleUrls: ['./time-expand.component.less'],
  providers: [TimeExpandService, CommonService],
})
export class TimeExpandComponent
  extends DynamicFormControlComponent
  implements OnInit
{
  @Input() formLayout: DynamicFormLayout;
  @Input() group: FormGroup;
  @Input() layout: DynamicFormControlLayout;
  @Input() model: DynamicTimeExpandModel;
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() blur: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() change: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() focus: EventEmitter<any> = new EventEmitter();
  @ViewChild('timeExpandTemplateRef') timeExpandTemplateRef: TemplateRef<any>;
  start_time: any;
  showTimeFormat = { nzFormat: 'HH:mm:ss' };
  finished: any;
  pageCode: any;
  constructor(
    protected changeRef: ChangeDetectorRef,
    protected layoutService: DynamicFormLayoutService,
    protected validationService: DynamicFormValidationService,
    protected elementRef: ElementRef,
    private timeExpandService: TimeExpandService,
    public commonService: CommonService,
    public modalService: AthModalService
  ) {
    super(layoutService, validationService, changeRef, elementRef);
  }
  ngOnInit() {
    this.commonService.content = this.model.content;
    this.finished = this.commonService.content.finished;
    this.pageCode = this.commonService.content.pageCode;
  }
  openModal(columns: number, modalType: AthGridModalType) {
    this.start_time = null;
    return this.modalService.create({
      nzTitle: '延长时间',
      nzWrapClassName: 'ath-grid-modal-wrap',
      nzContent: this.timeExpandTemplateRef,
      nzComponentParams: {
        span: columns,
        modalType: modalType,
      },
      gridConfig: {
        span: columns,
        modalType: modalType,
      },
      nzOnCancel: (): void => {},
      // eslint-disable-next-line no-shadow
      nzOnOk: (EventEmitter: any): Boolean => {
        // console.log('timeExpandTemplateRef', EventEmitter);
        const extend_info = [
          {
            id: this.group.get('id').value,
            start_time: this.start_time,
            // equipment_fault_info: this.group.value,
          },
        ];
        // TODO 需调整入参，需传入任务卡当前条目的完整数据
        this.timeExpandService
          .ca_efm_extend_time_info_process(extend_info)
          .then((res) => {});
        this.change.emit({
          type: 'application-submit',
        });
        this.changeRef.markForCheck();
        return true;
      },
    });
  }
  onChange(event) {}
}
