/* eslint-disable no-shadow */
/* eslint-disable quotes */
import {
  ChangeDetectorRef,
  Component,
  ElementRef,
  EventEmitter,
  Input,
  OnInit,
  Output,
  TemplateRef,
  ViewChild,
} from '@angular/core';
import { FormGroup } from '@angular/forms';
// eslint-disable-next-line max-len
import {
  DynamicFormControlComponent,
  DynamicFormControlLayout,
  DynamicFormLayout,
  DynamicFormLayoutService,
  DynamicFormService,
  DynamicFormValidationService,
} from '@athena/dynamic-core';
import { DynamicWorkOrderEffectModel } from 'app/implementation/model/work-order-effect/work-order-effect.model';
import { WorkOrderEffectService } from './work-order-effect.service';
import { CommonService } from 'app/implementation/service/common.service';
import { AthGridModalType } from '@athena/design-ui/components/modal/modal-types';
import { AthModalService } from '@athena/design-ui/src/components/modal';

import column from './column';
import { AthTableComponent } from '@athena/design-ui/src/components/table';
@Component({
  selector: 'app-work-order-effect',
  templateUrl: './work-order-effect.component.html',
  styleUrls: ['./work-order-effect.component.less'],
  providers: [WorkOrderEffectService, CommonService],
})
export class WorkOrderEffectComponent
  extends DynamicFormControlComponent
  implements OnInit
{
  @Input() formLayout: DynamicFormLayout;
  @Input() group: FormGroup;
  @Input() layout: DynamicFormControlLayout;
  @Input() model: DynamicWorkOrderEffectModel;
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() blur: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() change: EventEmitter<any> = new EventEmitter();
  // eslint-disable-next-line @angular-eslint/no-output-native
  @Output() focus: EventEmitter<any> = new EventEmitter();
  @ViewChild('workOrderTemplateRef') workOrderTemplateRef: TemplateRef<any>;
  // @ViewChild('athenaTable', { static: true }) athenaTable: AthTableComponent;
  @ViewChild('productPlanTemplateRef') productPlanTemplateRef: TemplateRef<any>;
  formGroup: FormGroup;
  columnDefs: any[] = [
    { headerName: '工单单号', field: 'man_no' },
    { headerName: '品号', field: 'item_no' },
    { headerName: '计划产量', field: 'plan_qty' },
    { headerName: '预计开工时间', field: 'plan_start_time' },
    { headerName: '预计完工时间', field: 'plan_end_time' },
  ];
  tableList = [];
  tableOrderList = [];
  current_mo: any;
  work_shop: any;
  product: any;
  plan_qty: any;
  faulty_equipment: any;
  classification_name: any;
  equipment_name: any;
  product_line: any;
  constructor(
    protected changeRef: ChangeDetectorRef,
    protected layoutService: DynamicFormLayoutService,
    protected validationService: DynamicFormValidationService,
    protected elementRef: ElementRef,
    private workOrderEffectService: WorkOrderEffectService,
    public modalService: AthModalService,
    public formService: DynamicFormService,
    public commonService: CommonService
  ) {
    super(layoutService, validationService, changeRef, elementRef);
  }

  ngOnInit() {
    this.commonService.content = this.model.content;
    // console.log('group', this.group.value);
    this.classification_name = this.group.get('classification_name').value;
    this.equipment_name = this.group.get('equipment_name').value;
    this.work_shop = this.group.get('workshop').value;
    this.product_line = this.group.get('product_line').value;
  }
  /**
   * 请求当前工单影响接口
   */
  getTableList() {
    this.workOrderEffectService.ca_efm_current_mo_info_get({}).then((res) => {
      console.log('res111', res);
      this.current_mo = res[0].current_mo; // 当前工单
      this.product = res[0].product; // 产品
      this.plan_qty = res[0].plan_qty; // 计划量
      this.tableOrderList = res[0].current_mo_detail;
      this.initTable();
    });
    this.workOrderEffectService
      .ca_efm_production_plan_info_get({})
      .then((res) => {
        this.tableList = res;
        // console.log('生产计划', this.tableList);
      });
  }
  openOrderModal(columns: number, modalType: AthGridModalType) {
    this.getTableList();
    return this.modalService.create({
      nzTitle: '当前工单影响',
      nzWrapClassName: 'ath-grid-modal-wrap',
      nzContent: this.workOrderTemplateRef,
      nzComponentParams: {
        span: columns,
        modalType: modalType,
      },
      gridConfig: {
        span: columns,
        modalType: modalType,
      },
      nzOnCancel: (): void => {},
    });
  }
  initTable() {
    const source = this.createDynamicTableJSON();
    source.layout = Array.isArray(source?.layout) ? source.layout : [];
    const initializedData = this.formService.initData(
      source.layout as any,
      source.pageData,
      source.rules as any,
      source.style
    );
    // this.formLayout = initializedData.formLayout; // 样式
    this.formModel = initializedData.formModel; // 组件数据模型
    this.formGroup = initializedData.formGroup; // formGroup
    //  this.group = initializedData.formGroup; // formGroup
  }

  createDynamicTableJSON() {
    const data = {
      layout: [
        {
          id: 'current_mo_info',
          type: 'ATHENA_TABLE',
          editable: true,
          disabledUserDefined: true,
          schema: 'current_mo_info',
          scriptFilters: [],
          setting: {
            hideDefaultToolbar: ['composite-sort', 'setting'],
          },
          columnDefs: this.getColumn(),
          allFields: [],
        },
      ],
      pageData: {
        current_mo_info: this.tableOrderList,
      },
      rules: [],
      content: {},
      style: {},
    };
    return data;
  }
  getColumn() {
    const materialcolums = JSON.parse(JSON.stringify(column));
    const res = materialcolums.map((column) => {
      return {
        ...column,
      };
    });
    return res;
  }

  openModal(columns: number, modalType: AthGridModalType) {
    return this.modalService.create({
      nzTitle: '后续生产计划',
      nzWrapClassName: 'ath-grid-modal-wrap',
      nzContent: this.productPlanTemplateRef,
      nzComponentParams: {
        span: columns,
        modalType: modalType,
      },
      gridConfig: {
        span: columns,
        modalType: modalType,
      },
      nzOnCancel: (): void => {},
    });
  }
}
