import {
  DynamicFormControlModel,
  parseReviver, isString,
  DynamicFormModelConvertService,
  cloneDeep,
  CustomAppConfigService
} from '@athena/dynamic-core';
import { Injectable } from '@angular/core';
import { SYSTEM_CONFIG } from 'app/config/system-config';
import { DYNAMIC_CUSTOM__ATHENA_FAULT_PLAN_ADD_ROW, DynamicFaultPlanAddRowModel } from '../model/fault-plan-add-row/fault-plan-add-row.model';
import { DYNAMIC_CUSTOM__ATHENA_FAULT_PLAN_OPERATE_FILED, DynamicFaultPlanOperateFiledModel } from '../model/fault-plan-operate-filed/fault-plan-operate-filed.model';
import { DYNAMIC_CUSTOM__ATHENA_WORK_ORDER_EFFECT, DynamicWorkOrderEffectModel } from '../model/work-order-effect/work-order-effect.model';
import { DYNAMIC_CUSTOM__ATHENA_PRODUCT_PLAN, DynamicProductPlanModel } from '../model/product-plan/product-plan.model';
import { DYNAMIC_CUSTOM__ATHENA_DEVICE_DETAIL, DynamicDeviceDetailModel } from '../model/device-detail/device-detail.model';
import { DYNAMIC_CUSTOM__ATHENA_DISPATCH_LIST, DynamicDispatchListModel } from '../model/dispatch-list/dispatch-list.model';
import { DYNAMIC_CUSTOM__ATHENA_SETTING_BTN, DynamicSettingBtnModel } from '../model/setting-btn/setting-btn.model';
import { DYNAMIC_CUSTOM__ATHENA_TIME_EXPAND, DynamicTimeExpandModel } from '../model/time-expand/time-expand.model';
import { DYNAMIC_CUSTOM__ATHENA_FAULT_COUNT, DynamicFaultCountModel } from '../model/fault-count/fault-count.model';
import { DYNAMIC_CUSTOM__ATHENA_FAULT_DETAIL_BTN, DynamicFaultDetailBtnModel } from '../model/fault-detail-btn/fault-detail-btn.model';
import { DYNAMIC_CUSTOM__ATHENA_KNOWLEDGE_BASE, DynamicKnowledgeBaseModel } from '../model/knowledge-base/knowledge-base.model';

@Injectable()
export class DynamicBusinessFormModelConvertService implements DynamicFormModelConvertService {
  constructor(
    public customAppConfigService: CustomAppConfigService
  ) { }

  fromOneJSON(
    json: string | object,
    content: any
  ): DynamicFormControlModel {
    let model;
    if (isString(json)) {
      model = isString(json);
    } else if (typeof json === 'object') {
      model = cloneDeep(json);
    } else {
      model = JSON.parse(JSON.stringify(json), parseReviver);
    }
    const layout = model.layout || null;
    let result: DynamicFormControlModel;
    model.content = content;
    switch (model.type) {
      case DYNAMIC_CUSTOM__ATHENA_KNOWLEDGE_BASE:
        result = new DynamicKnowledgeBaseModel(model, layout);
        break;
      case DYNAMIC_CUSTOM__ATHENA_FAULT_DETAIL_BTN:
        result = new DynamicFaultDetailBtnModel(model, layout);
        break;
      case DYNAMIC_CUSTOM__ATHENA_FAULT_COUNT:
        result = new DynamicFaultCountModel(model, layout);
        break;
      case DYNAMIC_CUSTOM__ATHENA_TIME_EXPAND:
        result = new DynamicTimeExpandModel(model, layout);
        break;
      case DYNAMIC_CUSTOM__ATHENA_SETTING_BTN:
        result = new DynamicSettingBtnModel(model, layout);
        break;
      case DYNAMIC_CUSTOM__ATHENA_DISPATCH_LIST:
        result = new DynamicDispatchListModel(model, layout);
        break;
      case DYNAMIC_CUSTOM__ATHENA_DEVICE_DETAIL:
        result = new DynamicDeviceDetailModel(model, layout);
        break;
      case DYNAMIC_CUSTOM__ATHENA_PRODUCT_PLAN:
        result = new DynamicProductPlanModel(model, layout);
        break;
      case DYNAMIC_CUSTOM__ATHENA_WORK_ORDER_EFFECT:
        result = new DynamicWorkOrderEffectModel(model, layout);
        break;
      case DYNAMIC_CUSTOM__ATHENA_FAULT_PLAN_OPERATE_FILED:
        result = new DynamicFaultPlanOperateFiledModel(model, layout);
        break;
      case DYNAMIC_CUSTOM__ATHENA_FAULT_PLAN_ADD_ROW:
        result = new DynamicFaultPlanAddRowModel(model, layout);
        break;
      default:
        break;
    }
    /** 渲染定制组件时，将应用信息传给service */
    if (!!result) { this.customAppConfigService.customConfig = { appCode: SYSTEM_CONFIG.dwAppId }; }
    return result;
  }
}
